<?php
namespace Aws\TimestreamInfluxDB\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Timestream InfluxDB** service.
 */
class TimestreamInfluxDBException extends AwsException {}
